<p align="center">
  <img width = "450" src="https://github.com/rodluger/starry/blob/master/docs/starry.png?raw=true"/>
  <br>
  <br>
  Tools for mapping stars and exoplanets.
  <p align="center">
    <!-- tests -->
    <a href="https://github.com/rodluger/starry/actions/workflows/tests.yml">
      <img src="https://github.com/rodluger/starry/actions/workflows/tests.yml/badge.svg" alt="Test status"/>
    </a>
    <!-- coverage -->
    <a href="https://coveralls.io/github/rodluger/starry">
      <img src="https://coveralls.io/repos/github/rodluger/starry/badge.svg?branch=master" alt="Coverage status"/>
    </a>
    <br/>
    <!-- build docs -->
    <a href='https://starry.readthedocs.io/en/latest/?badge=latest'>
    <img src='https://readthedocs.org/projects/starry/badge/?version=latest' alt="Documentation status" />
  </a>
    <!-- build notebooks -->
    <a href="https://starry.readthedocs.io/en/latest/tutorials/">
      <img src="https://github.com/rodluger/starry/actions/workflows/tutorials.yml/badge.svg" alt="Notebook status"/>
    </a>
    <!-- read the paper -->
    <a href="http://adsabs.harvard.edu/abs/2019AJ....157...64L">
      <img src="https://img.shields.io/badge/paper-Astronomical%20Journal-blue.svg?style=flat" alt="Read the paper"/>
    </a>
  </p>
</p>
